@@ -6,7 +6,8 @@ use Moo;
 use Encode ();
 
 # ABSTRACT: WebSocket message for AnyEvent
-our $VERSION = '0.47_01'; # TRIAL VERSION
+our $VERSION = '0.51_01'; # TRIAL VERSION
+$VERSION = eval $VERSION;
 
 
 has body => ( is => 'ro', required => 1 );
@@ -39,7 +40,7 @@ AnyEvent::WebSocket::Message - WebSocket message for AnyEvent
 
 =head1 VERSION
 
-version 0.47_01
+version 0.51_01
 
 =head1 SYNOPSIS
 
@@ -154,6 +155,8 @@ Yanick Champoux (YANICK)
 
 Fayland Lam (FAYLAND)
 
+Daniel Kamil Kozar (xavery)
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Graham Ollis.
